Index: content/public/browser/plugin_service_filter.h |
=================================================================== |
--- content/public/browser/plugin_service_filter.h (revision 180039) |
+++ content/public/browser/plugin_service_filter.h (working copy) |
@@ -13,20 +13,25 @@ |
namespace content { |
-// Callback class to let the client filter the list of all installed plug-ins. |
+// Callback class to let the client filter the list of all installed plug-ins |
+// and block them from being loaded. |
// This class is called on the FILE thread. |
class PluginServiceFilter { |
public: |
virtual ~PluginServiceFilter() {} |
// Whether to use |plugin|. The client can return false to disallow the |
// plugin, or return true and optionally change the passed in plugin. |
- virtual bool ShouldUsePlugin(int render_process_id, |
+ virtual bool IsPluginEnabled(int render_process_id, |
Bernhard Bauer
2013/02/04 13:58:53
Naming bikeshedding comment: I think this confuses
|
int render_view_id, |
const void* context, |
const GURL& url, |
const GURL& policy_url, |
webkit::WebPluginInfo* plugin) = 0; |
+ |
+ // Whether the renderer has permission to load enabled |plugin|. |
+ virtual bool CanLoadPlugin(int render_process_id, |
+ const FilePath& path) = 0; |
}; |
} // namespace content |
@@ -13,20 +13,25 @@ |
public: |
virtual ~PluginServiceFilter() {} |
- // Whether to use |plugin|. The client can return false to disallow the |
+ // Whether |plugin| is enabled. The client can return false to hide the |
// plugin, or return true and optionally change the passed in plugin. |